*ORIGINAL DATA FROM http://www.ats.ucla.edu/stat/sas/library/repeated_ut.htm;
OPTIONS NONUMBER NODATE NOCENTER PAGESIZE=MAX LINESIZE=120 formdlim='-';
* Kill default titles on output;
TITLE;

ODS LISTING;
ODS HTML CLOSE;
ODS RTF STYLE=HTMLBLUE FILE = "C:\Dropbox\!PSYC 943\Lectures\13 Multivariate Models with Predictors; MANOVA\SAS Example\test.rtf"  STARTPAGE=NO;

*ODS GRAPHICS ON;
*ODS HTML FILE="C:\Users\jtemplin2\Dropbox\!PSYC 943\Lectures\13 Multivariate Models with Predictors; *MANOVA\SAS Example\test.xls";

*MACRO FOR ANALYSIS OF THE R MATRIX;
%MACRO R_Matrix_Determinant(rmatrix_library,rmatrix_dataset,output_library,output_dataset,modelnum);
PROC IML;

	USE &rmatrix_library..&rmatrix_dataset.;
	READ ALL VAR _ALL_ INTO FullX;

	K = NCOL(FullX);

	COV = FullX[,3:K];
	DET_R = DET(COV);
	
	OUTPUTMAT = &modelnum. || DET_R;

	CNAME = {"modelnumber","Gen Variance R"};
	CREATE &output_library..&output_dataset. FROM OUTPUTMAT [COLNAME = cname];
	APPEND FROM OUTPUTMAT;

QUIT;

%MEND;


*VALUE LABELS FOR EACH LEVEL OF OUR CATEGORICAL VARIABLES;
PROC FORMAT;
VALUE exercises
    1 = "Aerobic Stair Climbing"
    2 = "Racquetball"
    3 = "Weight Training";

VALUE diets
    1 = "Meat Eaters"
    2 = "Vegetarians";

VALUE intensities
	1 = "Pulse: Warm Up"
	2 = "Pulse: Jogging"
	3 = "Pulse: Running";
RUN;


DATA work.dietwide;
INPUT exertype pulse1 pulse2 pulse3 diet personID;

*LABELING VARIABLES;
LABEL exertype = "Exercise Type"
      pulse1 = "Pulse After Warmup"
      pulse2 = "Pulse After Jogging"
      pulse3 = "Pulse After Running"
      diet = "Diet Type";

*ADDING VALUE LABELS TO VARIABLES;
FORMAT exertype exercises. diet diets.;

*CREATING DUMMY CODED VARIABLES FOR EXERCISE TYPE:;
IF exertype = 1 THEN DO; dEXERCISE_ASC = 1; dEXERCISE_R = 0; dEXERCISE_WT = 0; END;
IF exertype = 2 THEN DO; dEXERCISE_ASC = 0; dEXERCISE_R = 1; dEXERCISE_WT = 0; END;
IF exertype = 3 THEN DO; dEXERCISE_ASC = 0; dEXERCISE_R = 0; dEXERCISE_WT = 1; END;


*CREATING DUMMY CODED VARIABLES FOR DIET TYPE;
IF diet = 1 THEN DO; dDIET_M = 1; dDIET_V = 0; END;
IF diet = 2 THEN DO; dDIET_M = 0; dDIET_V = 1; END;

*IMPORTING DATA;
DATALINES;
1         112       166       215       1      1
1         111       166       225       1      2
1         89        132       189       1      3
1         95        134       186       2      4
1         66        109       150       2      5
1         69        119       177       2      6
2         125       177       241       1      7
2         85        117       186       1      8
2         97        137       185       1      9
2         93        151       217       2     10
2         77        122       178       2     11
2         78        119       173       2     12
3         81        134       205       1     13
3         88        133       180       1     14
3         88        157       224       1     15
3         58         99       131       2     16
3         85        132       186       2     17
3         78        110       164       2     18
;
RUN;


*CONVERTING DATA TO STACKED FORM FOR PROC MIXED;
DATA WORK.dietstack;
    SET WORK.dietwide;

	FORMAT intensity intensities.; *ADDING A FORMAT STATEMENT FOR INTENSITY VARIABLE;

	*FIRST OUTCOME: PULSE 1 (AFTER WARM UP);
	pulse = pulse1;
    intensity = 1; 
	dINTENSITY_W = 1; dINTENSITY_J = 0; dINTENSITY_R = 0; *DUMMY CODED VARIABLES FOR ANALYSIS;
    OUTPUT; *OUTPUT MAKES THE LINE OF DATA GET WRITTEN TO THE NEW DATA SET;

	*SECOND OUTCOME: PULSE 2 (AFTER JOGGING);
    pulse = pulse2;
    intensity = 2; 
	dINTENSITY_W = 0; dINTENSITY_J = 1; dINTENSITY_R = 0; 
    OUTPUT;
	
	*THIRD OUTCOME: PULSE 3 (AFTER RUNNING);
    pulse = pulse3;
    intensity = 3; 
	dINTENSITY_W = 0; dINTENSITY_J = 0; dINTENSITY_R = 1;
    OUTPUT;

RUN;

*PRINTING DATA IN NEW FORMAT FOR DEMONSTRATION;
PROC PRINT DATA=WORK.dietstack;
VAR personID pulse intensity dINTENSITY_W dINTENSITY_J dINTENSITY_R diet dDIET_V dDIET_M;
RUN;

*MODEL FROM LAST CLASS: MULTIVARIATE EMPTY MODEL/UN R MATRIX STRUCTURE;
TITLE "EMPTY MULTIVARIATE MODEL, FULL UNSTRUCTURED ERROR VARIANCE MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE) - MULTIVARIATE ANOVA ASSUMPTION";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED / SUBJECT=personID TYPE=UN R RCORR;
ODS OUTPUT INFOCRIT=info_model1 R=r_model1;
RUN;
TITLE;

*FOR MODEL COMPARISON;
DATA work.info_model1;
	SET work.info_model1;
	modelname = 'Empty Means; Unstructured Covariances (All Estimated)';
	modelnumber = 1;
RUN;

*CALCULATION OF GENERALIZED VARIANCE OF RMATRIX;
%R_Matrix_Determinant(work,R_model1,work,GV_R_model1,1);

*MERGE WITH INFORMATION CRITERIA FROM MODEL OUTPUT;
DATA work.info_model1;
	MERGE work.info_model1 work.GV_R_model1;
RUN;


TITLE "DIET TYPE MULTIVARIATE MODEL, FULL UNSTRUCTURED ERROR VARIANCE MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE) - MULTIVARIATE ANOVA ASSUMPTION";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
MODEL pulse = dINTENSITY_W dINTENSITY_R dDIET_V dDIET_V*dINTENSITY_W dDIET_V*dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED / SUBJECT=personID TYPE=UN R RCORR;
ODS OUTPUT INFOCRIT=info_model2 R=r_model2;
RUN;
TITLE;
*FOR MODEL COMPARISON;
DATA work.info_model2;
	SET work.info_model2;
	modelname = 'Diet; Unstructured Covariances (All Estimated)';
	modelnumber = 2;
RUN;

*CALCULATION OF GENERALIZED VARIANCE OF RMATRIX;
%R_Matrix_Determinant(work,R_model2,work,GV_R_model2,2);

*MERGE WITH INFORMATION CRITERIA FROM MODEL OUTPUT;
DATA work.info_model2;
	MERGE work.info_model2 work.GV_R_model2;
RUN;


TITLE "MULTIVARIATE MODEL WITH DIET PREDICTOR ONLY - NO CLASS STATEMENT";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
MODEL pulse = dDIET_V

			  dINTENSITY_W dDIET_V*dINTENSITY_W

			  dINTENSITY_R dDIET_V*dINTENSITY_R

			  / S DDFM=KENWARDROGER;

REPEATED / SUBJECT=personID TYPE=UN R RCORR;

*INVESTIGATING INTERACTION EFFECT OF INTENSITY*DIET;
ESTIMATE 'Predicted Pulse After Warmup for Vegetarians'  intercept 1 dINTENSITY_W 1 dDIET_V 1 dDIET_V*dINTENSITY_W 1;
ESTIMATE 'Predicted Pulse After Warmup for Meat Eaters'  intercept 1 dINTENSITY_W 1;
ESTIMATE 'Predicted Pulse After Jogging for Vegetarians' intercept 1 dDIET_V 1;
ESTIMATE 'Predicted Pulse After Jogging for Meat Eaters' intercept 1;
ESTIMATE 'Predicted Pulse After Running for Vegetarians' intercept 1 dINTENSITY_R 1 dDIET_V 1 dDIET_V*dINTENSITY_R 1;
ESTIMATE 'Predicted Pulse After Running for Meat Eaters' intercept 1 dINTENSITY_R 1;

* THE CONTRAST STATEMENT PROVIDES MULTIPLE DEGREE OF FREEDOM TESTS;
CONTRAST 'Within Subjects Test of Intensity*Diet' dDIET_V*dINTENSITY_W 1, dDIET_V*dINTENSITY_R 1;

*  POST HOC DIFFERENCES IN INTERACTION CELL MEANS  ------------------------------------------------------;
ESTIMATE 'Difference In Pulse After Warmup for Diet' dDIET_V 1 dDIET_V*dINTENSITY_W 1;
ESTIMATE 'Difference In Pulse After Jogging for Diet' dDIET_V 1;
ESTIMATE 'Difference in Pulse After Running for Diet' dDIET_V 1 dDIET_V*dINTENSITY_R 1;

ESTIMATE 'Difference in Pulse After Warmup and Pulse After Jogging for Vegetarians' dINTENSITY_W 1 dDIET_V*dINTENSITY_W 1;
ESTIMATE 'Difference in Pulse After Warmup and Pulse After Running for Vegetarians' dINTENSITY_W 1 dINTENSITY_R -1 dDIET_V*dINTENSITY_W 1 dDIET_V*dINTENSITY_R -1;
ESTIMATE 'Difference in Pulse After Jogging and Pulse After Running for Vegetarians' dINTENSITY_R -1 dDIET_V*dINTENSITY_R -1;

ESTIMATE 'Difference in Pulse After Warmup and Pulse After Jogging for Meat Eaters' dINTENSITY_W 1;
ESTIMATE 'Difference in Pulse After Warmup and Pulse After Running for Meat Eaters' dINTENSITY_W 1 dINTENSITY_R -1;
ESTIMATE 'Difference in Pulse After Jogging and Pulse After Running for Meat Eaters' dINTENSITY_R -1;

ESTIMATE 'Difference in Pulse After Warmup for Vegetarians and After Jogging for Meat Eaters' dDIET_V 1 dINTENSITY_W 1 dDIET_V*dINTENSITY_W 1;
ESTIMATE 'Difference in Pulse After Warmup for Vegetarians and After Running for Meat Eaters' dINTENSITY_W 1 dDIET_V 1 dDIET_V*dINTENSITY_W 1 dINTENSITY_R -1;

ESTIMATE 'Difference in Pulse After Warmup for Meat Eaters and After Jogging for Vegetarians' dINTENSITY_W 1 dDIET_V -1;
ESTIMATE 'Difference in Pulse After Warmup for Meat Eaters and After Running for Vegetarians' dINTENSITY_W 1 dINTENSITY_R -1 dDIET_V -1 dDIET_V*dINTENSITY_R -1;

ESTIMATE 'Difference in Pulse After Jogging for Vegetarians and Pulse After Running for Meat Eaters' dDIET_V 1 dINTENSITY_R -1;

ESTIMATE 'Difference in Pulse After Jogging for Meat Eaters and Pulse After Running for Vegetarians' dINTENSITY_R -1 dDIET_V -1 dDIET_V*dINTENSITY_R -1;

*INVESTIGATING MARGINAL EFFECT OF INTENSITY;
ESTIMATE 'Marginal Mean of Pulse After Warmup'  intercept 2 dINTENSITY_W 2 dDIET_V 1 dDIET_V*dINTENSITY_W 1 / DIVISOR = 2; 
ESTIMATE 'Marginal Mean of Pulse After Jogging' intercept 2 dDIET_V 1 / DIVISOR = 2;									  
ESTIMATE 'Marginal Mean of Pulse After Running' intercept 2 dINTENSITY_R 2 dDIET_V 1 dDIET_V*dINTENSITY_R 1 / DIVISOR = 2; 

CONTRAST 'Within Subjects Test of Intensity' dINTENSITY_W 1 dDIET_V*dINTENSITY_W .5, 
											 dINTENSITY_R -1 dDIET_V*dINTENSITY_R -.5;

* POST HOC DIFFERENCES IN MARGINAL CELL MEANS OF INTENSITY;
ESTIMATE 'Difference in Marginal Mean of Pulse After Warmup and Jogging'  dINTENSITY_W 2 dDIET_V*dINTENSITY_W 1 / DIVISOR = 2; 
ESTIMATE 'Difference in Marginal Mean of Pulse After Warmup and Running'  dINTENSITY_W 2 dINTENSITY_R -2 dDIET_V*dINTENSITY_W 1 dDIET_V*dINTENSITY_W -1/ DIVISOR = 2;									  
ESTIMATE 'Difference in Marginal Mean of Pulse After Jogging and Running' dINTENSITY_R -2 dDIET_V*dINTENSITY_R -1 / DIVISOR = 2; 

*INVESTIGATING MARGINAL EFFECT OF DIET;
ESTIMATE 'Marginal Mean of Vegetarians' intercept 3 dINTENSITY_W 1 dDIET_V 3 dDIET_V*dINTENSITY_W 1 dINTENSITY_R 1 dDIET_V*dINTENSITY_R 1/DIVISOR=3;
ESTIMATE 'Marginal Mean of Meat Eaters' intercept 3 dINTENSITY_W 1 dINTENSITY_R 1 /DIVISOR=3;

CONTRAST 'Between Subjects Test of Diet' dDIET_V .33 dDIET_V*dINTENSITY_W .33 dDIET_V*dINTENSITY_R .33; *dINTENSITY_W 1 dDIET_V 1;

* POST HOC DIFFERENCES IN MARGINAL CELL MEANS OF DIET;
ESTIMATE 'Difference Marginal Mean of Vegetarians and Meat Eaters' dDIET_V 3 dDIET_V*dINTENSITY_W 1 dDIET_V*dINTENSITY_R 1/DIVISOR=3;

RUN;
TITLE;




TITLE "MULTIVARIATE MODEL WITH DIET PREDICTOR ONLY - CLASS STATEMENT";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity diet;
MODEL pulse = intensity diet intensity*diet/ S DDFM=KENWARDROGER;
REPEATED / SUBJECT=personID TYPE=UN R RCORR;
LSMEANS intensity*diet / PDIFF=ALL SLICE=diet intensity; 
LSMEANS intensity*diet / SLICE=intensity;
LSMEANS intensity diet / PDIFF=ALL;

*INVESTIGATING INTERACTION EFFECT OF INTENSITY*DIET;
ESTIMATE 'Predicted Pulse After Warmup for Vegetarians'  intercept 1 diet 0 1 intensity 0 0 1 diet*intensity 0 0 0 0 0 1 / E;
ESTIMATE 'Predicted Pulse After Warmup for Meat Eaters'  intercept 1 diet 1 0 intensity 0 0 1 diet*intensity 0 0 0 0 1 0;
ESTIMATE 'Predicted Pulse After Jogging for Vegetarians' intercept 1 diet 0 1 intensity 0 1 0 diet*intensity 0 0 0 1 0 0;
ESTIMATE 'Predicted Pulse After Jogging for Meat Eaters' intercept 1 diet 1 0 intensity 0 1 0 diet*intensity 0 0 1 0 0 0;
ESTIMATE 'Predicted Pulse After Running for Vegetarians' intercept 1 diet 0 1 intensity 1 0 0 diet*intensity 0 1 0 0 0 0;
ESTIMATE 'Predicted Pulse After Running for Meat Eaters' intercept 1 diet 1 0 intensity 1 0 0 diet*intensity 1 0 0 0 0 0;

CONTRAST 'Within Subjects Test of Intensity*Diet' intensity 0 -1 1 diet -1 1 diet*intensity -.33 .33 -.83 -.17 .5 .5  ;

RUN;
TITLE;


TITLE "CLASSICAL MANOVA: MULTIVARIATE MODEL WITH DIET PREDICTOR ONLY";
*COMPARISON WITH MANOVA - RUNS CLASSICAL MANOVA ANALYSIS;
PROC GLM DATA=work.dietwide;
	MODEL pulse1 pulse2 pulse3 = DIET / SOLUTION NOUNI;
	MANOVA H=DIET / PRINTE;
RUN;
TITLE;

ODS RTF CLOSE;
